@@ -1,7 +1,7 @@
 package Getopt::Long::EvenLess;
 
 our $DATE = '2017-01-11'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 # let's be minimalistic
 #use strict 'subs', 'vars';
@@ -125,6 +125,7 @@ sub GetOptionsFromArray {
                 push @remaining, $argv->[$i];
                 next ELEM;
             } elsif (!length($opt)) {
+                push @remaining, $argv->[$i];
                 next ELEM; # ambiguous
             }
 
@@ -151,11 +152,22 @@ sub GetOptionsFromArray {
         } elsif ($argv->[$i] =~ /\A-(.*)/) {
 
             my $str = $1;
+            my $remaining_pushed;
           SHORT_OPT:
             while ($str =~ s/(.)//) {
                 my $used_name = $1;
-                my $opt = $code_find_opt->($1, 'short');
-                next SHORT_OPT unless defined($opt) && length($opt);
+                my $short_opt = $1;
+                my $opt = $code_find_opt->($short_opt, 'short');
+                if (!defined $opt) {
+                    # unknown short option
+                    push @remaining, "-" unless $remaining_pushed++;
+                    $remaining[-1] .= $short_opt;
+                    next SHORT_OPT;
+                } elsif (!length $opt) {
+                    # ambiguous short option
+                    push @remaining, "-" unless $remaining_pushed++;
+                    $remaining[-1] .= $short_opt;
+                }
 
                 my $spec = $spec_by_opt_name{$opt};
                 # check whether option requires an argument
@@ -167,8 +179,10 @@ sub GetOptionsFromArray {
                     } else {
                         if ($i+1 >= @$argv) {
                             # we are the last element
-                            warn "Option $used_name requires an argument\n";
-                            $success = 0;
+                            unless ($config->{pass_through}) {
+                                warn "Option $used_name requires an argument\n";
+                                $success = 0;
+                            }
                             last ELEM;
                         }
                         # take the next element as argument
@@ -212,7 +226,7 @@ Getopt::Long::EvenLess - Like Getopt::Long::Less, but with even less features
 
 =head1 VERSION
 
-This document describes version 0.09 of Getopt::Long::EvenLess (from Perl distribution Getopt-Long-EvenLess), released on 2017-01-11.
+This document describes version 0.10 of Getopt::Long::EvenLess (from Perl distribution Getopt-Long-EvenLess), released on 2017-01-11.
 
 =head1 DESCRIPTION
 
@@ -275,22 +289,22 @@ handler, etc.
 B<Startup overhead>. Here's a sample startup overhead benchmark:
 
                            Rate     load_gl      run_gl load_gl_less run_gl_less run_gl_evenless load_gl_evenless   perl
- load_gl          69.66+-0.18/s          --       -0.4%       -68.6%      -69.2%          -82.2%           -82.7% -89.1%
- run_gl            69.95+-0.2/s 0.42+-0.38%          --       -68.5%      -69.1%          -82.1%           -82.6% -89.0%
- load_gl_less      222.1+-1.1/s 218.8+-1.8% 217.5+-1.8%           --       -1.9%          -43.3%           -44.8% -65.1%
- run_gl_less       226.3+-1.9/s 224.9+-2.8% 223.6+-2.8%  1.92+-0.99%          --          -42.2%           -43.7% -64.4%
- run_gl_evenless   391.6+-3.9/s 462.2+-5.8% 459.9+-5.8%     76.4+-2%    73+-2.2%              --            -2.6% -38.5%
- load_gl_evenless    402+-1.1/s 477.1+-2.2% 474.6+-2.3%       81+-1%  77.6+-1.6%       2.6+-1.1%               -- -36.8%
- perl              636.3+-6.1/s 813.5+-9.1% 809.6+-9.1%  186.5+-3.1% 181.1+-3.6%      62.5+-2.2%       58.3+-1.6%     --
+ load_gl          69.45+-0.11/s          --       -1.9%       -69.1%      -69.9%          -81.5%           -82.5% -89.8%
+ run_gl           70.77+-0.19/s  1.9+-0.32%          --       -68.5%      -69.3%          -81.2%           -82.2% -89.7%
+ load_gl_less      224.7+-2.1/s   223.6+-3%   217.5+-3%           --       -2.5%          -40.2%           -43.5% -67.1%
+ run_gl_less       230.4+-1.8/s 231.8+-2.7% 225.6+-2.7%    2.5+-1.2%          --          -38.6%           -42.0% -66.3%
+ run_gl_evenless   375.5+-4.6/s 440.7+-6.6% 430.6+-6.6%   67.1+-2.5%  62.9+-2.4%              --            -5.6% -45.1%
+ load_gl_evenless  397.6+-2.2/s 472.5+-3.3% 461.8+-3.5%   76.9+-1.9%  72.6+-1.7%       5.9+-1.4%               -- -41.9%
+ perl                684+-5.1/s 884.9+-7.6% 866.5+-7.7%  204.4+-3.6% 196.8+-3.2%      82.2+-2.6%         72+-1.6%     --
  
  Average times:
-   perl            :     1.5716ms
-   load_gl_evenless:     2.4876ms
-   run_gl_evenless :     2.5536ms
-   run_gl_less     :     4.4189ms
-   load_gl_less    :     4.5025ms
-   run_gl          :    14.2959ms
-   load_gl         :    14.3554ms
+   perl            :     1.4620ms
+   load_gl_evenless:     2.5151ms
+   run_gl_evenless :     2.6631ms
+   run_gl_less     :     4.3403ms
+   load_gl_less    :     4.4504ms
+   run_gl          :    14.1303ms
+   load_gl         :    14.3988ms
 
 =head1 FUNCTIONS
 
